@@ -2,7 +2,7 @@
 
 .onLoad <- function(libname, pkgname)
 {
-  cat("How to use CEM? Type vignette(\"cem\")\n")
+  cat("\nHow to use CEM? Type vignette(\"cem\")\n")
 # library.dynam("cem", pkgname, libname) 
 }
 
